[java-idp-integration-tests] 02/02: IDP-1064 - Fix test

Tom Zeller tzeller at dragonacea.biz
Mon Oct 17 15:55:58 EDT 2016


This is an automated email from the git hooks/post-receive script.

tzeller pushed a commit to branch master
in repository java-idp-integration-tests.

View the commit online:
http://git.shibboleth.net/view/?p=java-idp-integration-tests.git;a=commit;h=9167d1de83bbf56b2170c08734608a1cd533975d

commit 9167d1de83bbf56b2170c08734608a1cd533975d
Author: Tom Zeller <tzeller at dragonacea.biz>
AuthorDate: Mon Oct 17 14:55:40 2016 -0500

    IDP-1064 - Fix test
---
 .../net/shibboleth/idp/test/saml2/AbstractSAML2IntegrationTest.java    | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/src/test/java/net/shibboleth/idp/test/saml2/AbstractSAML2IntegrationTest.java b/src/test/java/net/shibboleth/idp/test/saml2/AbstractSAML2IntegrationTest.java
index c600421..eeca137 100644
--- a/src/test/java/net/shibboleth/idp/test/saml2/AbstractSAML2IntegrationTest.java
+++ b/src/test/java/net/shibboleth/idp/test/saml2/AbstractSAML2IntegrationTest.java
@@ -623,9 +623,10 @@ public abstract class AbstractSAML2IntegrationTest extends BaseIntegrationTest {
      */
     public void testSSOReleaseLDAPAttributes(@Nullable final BrowserData browserData) throws Exception {
 
         // Only the mail attribute is released from LDAP by default
         validator.expectedAttributes.clear();
         validator.expectedAttributes.add(validator.mailAttribute);
+        validator.expectedAttributes.add(validator.uidAttribute);
 
         enableAttributeResolverLDAP();
 
@@ -623,9 +623,10 @@ public abstract class AbstractSAML2IntegrationTest extends BaseIntegrationTest {
     public void testSSOReleaseLDAPAttributes(@Nullable final BrowserData browserData) throws Exception {
 
-        // Only the mail attribute is released from LDAP by default
+        // Only the mail and uid attributes are released from LDAP by default
         validator.expectedAttributes.clear();
         validator.expectedAttributes.add(validator.mailAttribute);

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list